@@ -17,12 +17,12 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include "MainWindow.h"
+#include <MainWindow.h>
 
-#include <osmscout/util/Logger.h>
+#include <osmscout/log/Logger.h>
 
 #include <QGuiApplication>
-#include "SettingsDialog.h"
+#include <SettingsDialog.h>
 
 using namespace osmscout;
 
@@ -30,13 +30,5 @@ MainWindow::MainWindow(const DBThreadRef& dbThread)
  : QQmlApplicationEngine(QUrl("qrc:/qml/main.qml")),
    dbThread(dbThread)
 {
-  connect(dbThread.get(),
-          SIGNAL(initialisationFinished(const DatabaseLoadedResponse&)),
-          this,
-          SLOT(InitialisationFinished(const DatabaseLoadedResponse&)));
-}
-
-void MainWindow::InitialisationFinished(const DatabaseLoadedResponse& /*response*/)    // NOLINT
-{
-  osmscout::log.Info() << "InitialisationFinished()";
+  dbThread->databaseLoadFinished.Connect(dbLoadedSlot);
 }
