@@ -22,19 +22,23 @@
 
 #include <QQmlApplicationEngine>
 
-#include <osmscoutclientqt/Settings.h>
+#include <osmscoutclient/Settings.h>
+
 #include <osmscoutclientqt/MapWidget.h>
 
 class MainWindow : public QQmlApplicationEngine
 {
   Q_OBJECT
 
-public slots:
-  void InitialisationFinished(const osmscout::DatabaseLoadedResponse& response);
-
 private:
   osmscout::DBThreadRef dbThread;
 
+  osmscout::Slot<osmscout::GeoBox> dbLoadedSlot{
+    [](const osmscout::GeoBox &) {
+      osmscout::log.Info() << "InitialisationFinished()";
+    }
+  };
+
 public:
   explicit MainWindow(const osmscout::DBThreadRef& dbThread);
 };
