@@ -19,12 +19,16 @@
 
 #include <iostream>
 #include <iomanip>
+#include <sstream>
 #include <limits>
 #include <tuple>
 
-#include "config.h"
+#include <config.h>
+
+#include <osmscout/db/Database.h>
+
+#include <osmscout/projection/TileProjection.h>
 
-#include <osmscout/Database.h>
 #include <osmscoutmap/MapService.h>
 
 #if defined(HAVE_LIB_OSMSCOUTMAPCAIRO)
@@ -53,8 +57,8 @@
 #include <gperftools/heap-profiler.h>
 #include <malloc.h> // mallinfo
 #else
-#if defined(HAVE_MALLINFO)
-#include <malloc.h> // mallinfo
+#if defined(HAVE_MALLINFO2)
+#include <malloc.h> // mallinfo2
 #endif
 #endif
 
@@ -62,7 +66,7 @@
 
 #include <osmscout/system/Math.h>
 
-#include <osmscout/util/CmdLineParsing.h>
+#include <osmscout/cli/CmdLineParsing.h>
 #include <osmscout/util/StopClock.h>
 #include <osmscout/util/Tiling.h>
 
@@ -773,7 +777,7 @@ int main(int argc, char* argv[])
   osmscout::MapServiceRef     mapService=std::make_shared<osmscout::MapService>(database);
 
   if (!database->Open(args.databaseDirectory)) {
-    std::cerr << "Cannot open database" << std::endl;
+    std::cerr << "Cannot open db" << std::endl;
     return 1;
   }
 
@@ -835,7 +839,6 @@ int main(int argc, char* argv[])
       osmscout::MapData       data;
       osmscout::OSMTileIdBox  tileBox(osmscout::OSMTileId(tile.GetX()-1,tile.GetY()-1),
                                       osmscout::OSMTileId(tile.GetX()+1,tile.GetY()+1));
-      osmscout::GeoBox        boundingBox;
 
       if ((current % delta)==0) {
         std::cout << current*100/tileCount << "% " << current;
@@ -854,7 +857,6 @@ int main(int argc, char* argv[])
                      args.TileWidth(),
                      args.TileHeight());
 
-      projection.GetDimensions(boundingBox);
       projection.SetLinearInterpolationUsage(level.Get() >= 10);
 
       for (size_t i=0; i<args.loadRepeat; i++) {
@@ -884,11 +886,11 @@ int main(int argc, char* argv[])
         }
         struct mallinfo alloc_info = tc_mallinfo();
 #else
-#if defined(HAVE_MALLINFO)
-        struct mallinfo alloc_info = mallinfo();
+#if defined(HAVE_MALLINFO2)
+        struct mallinfo2 alloc_info = mallinfo2();
 #endif
 #endif
-#if defined(HAVE_MALLINFO) || defined(PERF_TEST_GPERFTOOLS_USAGE)
+#if defined(HAVE_MALLINFO2) || defined(PERF_TEST_GPERFTOOLS_USAGE)
         std::cout << "memory usage: " << formatAlloc(alloc_info.uordblks) << std::endl;
         stats.allocMax = std::max(stats.allocMax, (double) alloc_info.uordblks);
         stats.allocSum = stats.allocSum + (double) alloc_info.uordblks;
@@ -904,10 +906,10 @@ int main(int argc, char* argv[])
           tiles.clear(); // following flush method removes only tiles with use_count() == 1
           mapService->FlushTileCache();
 
-          // simplest way howto flush database caches is close it and open again
+          // simplest way howto flush db caches is close it and open again
           database->Close();
           if (!database->Open(args.databaseDirectory)) {
-            std::cerr << "Cannot open database" << std::endl;
+            std::cerr << "Cannot open db" << std::endl;
             return 1;
           }
         }
@@ -971,7 +973,7 @@ int main(int argc, char* argv[])
     std::cout << "Level: " << stats.level << std::endl;
     std::cout << "Tiles: " << stats.tileCount << " (load " << args.loadRepeat << "x, drawn " << args.drawRepeat << "x)" << std::endl;
 
-#if defined(HAVE_MALLINFO) || defined(PERF_TEST_GPERFTOOLS_USAGE)
+#if defined(HAVE_MALLINFO2) || defined(PERF_TEST_GPERFTOOLS_USAGE)
     std::cout << " Used memory: ";
     std::cout << "max: " << formatAlloc(stats.allocMax) << " ";
     std::cout << "avg: " << formatAlloc(stats.allocSum / (stats.tileCount * args.loadRepeat)) << std::endl;
