@@ -21,7 +21,10 @@
 #include <osmscoutclientqt/OSMScoutQt.h>
 #include <osmscoutclientqt/LookupModule.h>
 
-#include <osmscout/util/Logger.h>
+#include <osmscout/log/Logger.h>
+
+#include <QThreadPool>
+
 #include <iostream>
 
 namespace osmscout {
@@ -162,9 +165,9 @@ bool SearchLocationsRunnable::SearchLocations(DBInstanceRef &db,
     QList<LocationEntry> locations;
     QList<osmscout::ObjectFileRef> objectSet;
     osmscout::TextSearchIndex textSearch;
-    if(!textSearch.Load(db->path.toStdString())){
-      osmscout::log.Warn() << "Failed to load text index files, search only for locations with database " << db->path.toStdString();
-      return true; // silently continue, text indexes are optional in database
+    if(!textSearch.Load(db->path)){
+      osmscout::log.Warn() << "Failed to load text index files, search only for locations with db " << db->path;
+      return true; // silently continue, text indexes are optional in db
     }
     osmscout::TextSearchIndex::ResultsMap resultsTxt;
     textSearch.Search(searchPattern.toStdString(),
@@ -314,8 +317,8 @@ bool FreeTextSearchRunnable::BuildLocationEntry(const osmscout::ObjectFileRef& o
     }
     */
 
-    LocationEntry location(LocationEntry::typeObject, name, altName, objectType, adminRegionList,
-                           db->path, coordinates, bbox);
+    LocationEntry location(LocationInfo::Type::typeObject, name, altName, objectType, adminRegionList,
+                           QString::fromStdString(db->path), coordinates, bbox);
     location.addReference(object);
     locations.append(location);
 
@@ -351,8 +354,8 @@ bool SearchLocationsRunnable::BuildLocationEntry(const osmscout::LocationSearchR
 
       osmscout::log.Debug() << "address:  " << label.toStdString();
 
-      LocationEntry location(LocationEntry::typeObject, label, altName, objectType, adminRegionList,
-                             db->path, coordinates, bbox);
+      LocationEntry location(LocationInfo::Type::typeObject, label, altName, objectType, adminRegionList,
+                             QString::fromStdString(db->path), coordinates, bbox);
       location.addReference(entry.address->object);
       locations.append(location);
     }
@@ -366,8 +369,8 @@ bool SearchLocationsRunnable::BuildLocationEntry(const osmscout::LocationSearchR
 
       osmscout::log.Debug() << "loc:      " << loc.toStdString();
 
-      LocationEntry location(LocationEntry::typeObject, loc, altName, objectType, adminRegionList,
-                             db->path, coordinates, bbox);
+      LocationEntry location(LocationInfo::Type::typeObject, loc, altName, objectType, adminRegionList,
+                             QString::fromStdString(db->path), coordinates, bbox);
 
       for (auto object : entry.location->objects) {
           location.addReference(object);
@@ -383,8 +386,8 @@ bool SearchLocationsRunnable::BuildLocationEntry(const osmscout::LocationSearchR
       }
       osmscout::log.Debug() << "poi:      " << poi.toStdString();
 
-      LocationEntry location(LocationEntry::typeObject, poi, altName, objectType, adminRegionList,
-                             db->path, coordinates, bbox);
+      LocationEntry location(LocationInfo::Type::typeObject, poi, altName, objectType, adminRegionList,
+                             QString::fromStdString(db->path), coordinates, bbox);
       location.addReference(entry.poi->object);
       locations.append(location);
     }
@@ -395,8 +398,8 @@ bool SearchLocationsRunnable::BuildLocationEntry(const osmscout::LocationSearchR
       QString regionName=QString::fromStdString(entry.adminRegion->name);
 
       //=QString::fromUtf8(entry.adminRegion->name.c_str());
-      LocationEntry location(LocationEntry::typeObject, regionName, altName, objectType, adminRegionList,
-                             db->path, coordinates, bbox);
+      LocationEntry location(LocationInfo::Type::typeObject, regionName, altName, objectType, adminRegionList,
+                             QString::fromStdString(db->path), coordinates, bbox);
 
       osmscout::log.Debug() << "region: " << regionName.toStdString();
 
