@@ -24,7 +24,10 @@
 #include <osmscoutclientqt/TiledRenderingHelper.h>
 
 #include <osmscout/system/Math.h>
-#include <osmscout/util/Logger.h>
+#include <osmscout/log/Logger.h>
+
+#include <QGuiApplication>
+#include <QScreen>
 
 namespace osmscout {
 TiledMapRenderer::TiledMapRenderer(QThread *thread,
@@ -50,19 +53,20 @@ TiledMapRenderer::TiledMapRenderer(QThread *thread,
   onlineTilesEnabled = settings->GetOnlineTilesEnabled();
   offlineTilesEnabled = settings->GetOfflineMap();
 
-  connect(settings.get(), &Settings::OnlineTileProviderIdChanged,
+  settings->onlineTileProviderChanged.Connect(onlineTileProviderSlot);
+  settings->onlineTilesEnabledChanged.Connect(onlineTileEnabledSlot);
+  settings->offlineMapChanged.Connect(offlineMapChangedSlot);
+
+  connect(this, &TiledMapRenderer::onlineTileProviderSignal,
           this, &TiledMapRenderer::onlineTileProviderChanged,
           Qt::QueuedConnection);
-  connect(settings.get(), &Settings::OnlineTilesEnabledChanged,
+  connect(this, &TiledMapRenderer::onlineTilesEnabledSignal,
           this, &TiledMapRenderer::onlineTilesEnabledChanged,
           Qt::QueuedConnection);
-  connect(settings.get(), &Settings::OfflineMapChanged,
+  connect(this, &TiledMapRenderer::offlineMapChangedSignal,
           this, &TiledMapRenderer::onOfflineMapChanged,
           Qt::QueuedConnection);
 
-  connect(dbThread.get(), &DBThread::databaseLoadFinished,
-          this, &TiledMapRenderer::onDatabaseLoaded,
-          Qt::QueuedConnection);
   //
   // Make sure that we always decouple caller and receiver even if they are running in the same thread
   // else we might get into a dead lock
@@ -88,12 +92,12 @@ void TiledMapRenderer::Initialize()
 {
   {
     QMutexLocker locker(&lock);
-    qDebug() << "Initialize";
+    osmscout::log.Debug() << "Initialize";
 
     // create tile downloader in correct thread
     tileDownloader = new OsmTileDownloader(tileCacheDirectory,settings->GetOnlineTileProvider());
 
-    connect(settings.get(), &Settings::OnlineTileProviderChanged,
+    connect(this, &TiledMapRenderer::onlineTileProviderSignal,
             tileDownloader, &OsmTileDownloader::onlineTileProviderChanged,
             Qt::QueuedConnection);
 
@@ -134,8 +138,14 @@ void TiledMapRenderer::onStylesheetFilenameChanged()
                                    fillColor.GetG(),
                                    fillColor.GetB(),
                                    fillColor.GetA());
-              break;
             }
+
+            tileGridColor=QColor::fromRgbF(0.8,0.8,0.8);
+            if (styledConfig->HasFlag("daylight") && !styledConfig->GetFlagByName("daylight")) {
+              tileGridColor=QColor::fromRgbF(0.2,0.2,0.2);
+            }
+
+            break;
           }
         }
       }
@@ -181,7 +191,7 @@ bool TiledMapRenderer::RenderMap(QPainter& painter,
   onlineTileCache.clearPendingRequests();
   offlineTileCache.clearPendingRequests();
 
-  if (!TiledRenderingHelper::RenderTiles(painter,request,layerCaches,unknownColor)){
+  if (!TiledRenderingHelper::RenderTiles(painter,request,layerCaches,unknownColor,-1,tileGridColor)){
     return false;
   }
 
@@ -209,7 +219,7 @@ void TiledMapRenderer::onDatabaseLoaded(osmscout::GeoBox boundingBox)
   {
     QMutexLocker locker(&tileCacheMutex);
     onlineTileCache.invalidate(boundingBox);
-    offlineTileCache.invalidate(boundingBox);
+    offlineTileCache.incEpoch();
   }
 
   emit Redraw();
@@ -262,7 +272,7 @@ void TiledMapRenderer::offlineTileRequest(uint32_t zoomLevel, uint32_t xtile, ui
     }
 
     DatabaseCoverage state = databaseCoverageOfTile(zoomLevel, xtile, ytile);
-    // render offline map when area is fully covered by database or online tiles are disabled -> render basemap
+    // render offline map when area is fully covered by db or online tiles are disabled -> render basemap
     bool render = (state != DatabaseCoverage::Outside) || (!onlineTilesEnabled);
     if (render) {
         // tile rendering have sub-linear complexity with area size
@@ -311,7 +321,7 @@ void TiledMapRenderer::offlineTileRequest(uint32_t zoomLevel, uint32_t xtile, ui
                 this, &TiledMapRenderer::onLoadJobFinished);
 
         if (offlineTilesEnabled) {
-          dbThread->RunJob(loadJob);
+          dbThread->RunJob(std::bind(&DBLoadJob::Run, loadJob, std::placeholders::_1, std::placeholders::_2, std::placeholders::_3));
         } else {
           // offline map rendering is disabled but there are some overlay objects intersecting with the tile...
           onLoadJobFinished(QMap<QString,QMap<osmscout::TileKey,osmscout::TileRef>>());
@@ -354,7 +364,7 @@ void TiledMapRenderer::tileDownloadFailed(uint32_t zoomLevel, uint32_t x, uint32
     }
 }
 
-void TiledMapRenderer::onlineTileProviderChanged()
+void TiledMapRenderer::onlineTileProviderChanged(const OnlineTileProvider&)
 {
     {
         QMutexLocker locker(&tileCacheMutex);
@@ -429,8 +439,8 @@ void TiledMapRenderer::onLoadJobFinished(QMap<QString,QMap<osmscout::TileKey,osm
     drawParameter.SetPatternMode(osmscout::MapParameter::PatternMode::Scalable);
     drawParameter.SetIconPaths(paths);
     drawParameter.SetPatternPaths(paths);
-    drawParameter.SetDebugData(false);
-    drawParameter.SetDebugPerformance(true);
+    drawParameter.SetDebugData(osmscout::log.IsDebug());
+    drawParameter.SetDebugPerformance(osmscout::log.IsWarn());
 
     // optimize process can reduce number of nodes before rendering
     // it helps for slow renderer backend, but it cost some cpu
@@ -464,8 +474,7 @@ void TiledMapRenderer::onLoadJobFinished(QMap<QString,QMap<osmscout::TileKey,osm
 
     // overlay ways
     std::vector<OverlayObjectRef> overlayObjects;
-    osmscout::GeoBox renderBox;
-    projection.GetDimensions(renderBox);
+    osmscout::GeoBox renderBox(projection.GetDimensions());
     getOverlayObjects(overlayObjects, renderBox);
 
     //DrawMap(p, tileVisualCenter, loadZ, canvas.width(), canvas.height());
@@ -480,11 +489,12 @@ void TiledMapRenderer::onLoadJobFinished(QMap<QString,QMap<osmscout::TileKey,osm
                       /*drawCanvasBackground*/ false,
                       /*renderBasemap*/ !onlineTilesEnabled,
                       offlineTilesEnabled);
-      dbThread->RunJob(&job);
+      dbThread->RunJob(std::bind(&DBRenderJob::Run, &job, std::placeholders::_1, std::placeholders::_2, std::placeholders::_3));
       success=job.IsSuccess();
     }
 
     // this slot is called from DBLoadJob, we can't delete it now
+    loadJob->Close();
     loadJob->deleteLater();
     loadJob=nullptr;
 
@@ -499,7 +509,7 @@ void TiledMapRenderer::onLoadJobFinished(QMap<QString,QMap<osmscout::TileKey,osm
         QMutexLocker tileCacheLocker(&tileCacheMutex);
 
         if (loadEpoch != offlineTileCache.getEpoch()){
-          qWarning() << "Rendered from outdated data" << loadEpoch << "!=" << offlineTileCache.getEpoch();
+          osmscout::log.Warn() << "Rendered from outdated data" << loadEpoch << "!=" << offlineTileCache.getEpoch();
         }
 
         if (width == 1 && height == 1){
