@@ -27,7 +27,7 @@
 
 #include <osmscoutgpx/Import.h>
 
-#include <osmscout/util/Logger.h>
+#include <osmscout/log/Logger.h>
 
 #include <osmscout/system/Assert.h>
 
@@ -335,12 +335,20 @@ public:
     return xmlGetPredefinedEntity(name);
   }
 
-  static void StructuredErrorHandler(void* data, xmlErrorPtr error)
+  // overloaded method for libxml2 >= 2.12.0
+  static void StructuredErrorHandler(void* data, const xmlError *error)
   {
     auto* parser=static_cast<GpxParser*>(data);
     parser->Error("XML error, line " + std::to_string(error->line) + ": " + error->message);
   }
 
+  // overloaded method for libxml2 < 2.12.0
+  [[maybe_unused]]
+  static void StructuredErrorHandler(void* data, xmlErrorPtr error)
+  {
+    StructuredErrorHandler(data, static_cast<const xmlError*>(error));
+  }
+
   static void WarningHandler(void* data, const char* msg,...)
   {
     auto* parser=static_cast<GpxParser*>(data);
