@@ -22,14 +22,18 @@
 #include <numeric>
 #include <vector>
 
-#include <osmscout/TypeFeatures.h>
 #include <osmscout/FeatureReader.h>
 
-#include <osmscout/AreaAreaIndex.h>
-#include <osmscout/AreaDataFile.h>
+#include <osmscout/feature/AddressFeature.h>
+#include <osmscout/feature/LocationFeature.h>
+#include <osmscout/feature/NameFeature.h>
+#include <osmscout/feature/PostalCodeFeature.h>
 
-#include <osmscout/util/File.h>
-#include <osmscout/util/FileScanner.h>
+#include <osmscout/db/AreaAreaIndex.h>
+#include <osmscout/db/AreaDataFile.h>
+
+#include <osmscout/io/File.h>
+#include <osmscout/io/FileScanner.h>
 #include <osmscout/util/GeoBox.h>
 #include <osmscout/util/Geometry.h>
 
