@@ -19,7 +19,7 @@
 
 #include <osmscoutimport/GenCoordDat.h>
 
-#include <osmscout/private/Config.h>
+#include <osmscoutimport/private/Config.h>
 
 #if defined(HAVE_STD_EXECUTION)
   #include <execution>
@@ -27,10 +27,10 @@
 #include <limits>
 #include <map>
 
-#include <osmscout/CoordDataFile.h>
+#include <osmscout/db/CoordDataFile.h>
 
-#include <osmscout/util/ProcessingQueue.h>
-#include <osmscout/util/Worker.h>
+#include <osmscout/async/ProcessingQueue.h>
+#include <osmscout/async/Worker.h>
 
 #include <osmscoutimport/Preprocess.h>
 #include <osmscoutimport/RawCoord.h>
