@@ -21,12 +21,15 @@
 
 #include <algorithm>
 
-#include <osmscout/TypeFeatures.h>
 #include <osmscout/TypeInfoSet.h>
 
+#include <osmscout/feature/NameFeature.h>
+#include <osmscout/feature/RefFeature.h>
+
 #include <osmscout/system/Assert.h>
 
 #include <osmscout/util/Geometry.h>
+
 #include <osmscoutimport/Preprocess.h>
 #include <osmscoutimport/GenRawNodeIndex.h>
 #include <osmscoutimport/GenRawWayIndex.h>
@@ -139,8 +142,7 @@ namespace osmscout {
       if (sub->relationRole!=MultipolygonPart::none){
         MultipolygonPart::RelationRole expectedRole = id % 2 == 0 ? MultipolygonPart::inner : MultipolygonPart::outer;
         if (sub->relationRole != expectedRole) {
-          progress.Error("Ring " + std::to_string(sub->id) + " has invalid role, continue");
-          continue;
+          progress.Warning("Ring " + std::to_string(sub->id) + " has invalid role " + sub->GetRelationRoleStr() + ", expecting " + MultipolygonPart::GetRelationRoleStr(expectedRole));
         }
       }
 
