@@ -22,8 +22,7 @@
 #include <iostream>
 #include <algorithm>
 
-#include <osmscout/TypeFeatures.h>
-#include <osmscout/WaterIndex.h>
+#include <osmscout/db/WaterIndex.h>
 
 #include <osmscout/system/Assert.h>
 #include <osmscout/system/Math.h>
