@@ -34,8 +34,9 @@
 
 #include <osmscoutmapgdi/MapPainterGDI.h>
 
+#include <osmscout/io/File.h>
+
 #include <osmscout/util/String.h>
-#include <osmscout/util/File.h>
 
 namespace osmscout {
 
@@ -349,8 +350,7 @@ namespace osmscout {
 
       result.emplace_back();
       result.back().glyph.character = WStringToUTF8String(buffer.data());
-      result.back().position.SetX(horizontalOffset);
-      result.back().position.SetY(0);
+      result.back().position=Vertex2D(horizontalOffset,0);
 
       Gdiplus::RectF bb;
 
@@ -365,7 +365,7 @@ namespace osmscout {
     return result;
   }
 
-  DoubleRectangle MapPainterGDI::GlyphBoundingBox(const NativeGlyph &glyph) const {
+  ScreenVectorRectangle MapPainterGDI::GlyphBoundingBox(const NativeGlyph &glyph) const {
     return {0.0,
             (double) (glyph.height * -1),
             (double) glyph.width,
@@ -403,7 +403,7 @@ namespace osmscout {
 
   void MapPainterGDI::DrawLabel(const Projection &projection,
                                 const MapParameter &parameter,
-                                const DoubleRectangle &labelRectangle,
+                                const ScreenVectorRectangle &labelRectangle,
                                 const LabelData &label,
                                 const NativeLabel &/*layout*/) {
     RENDEROBJECT(pRender);
@@ -541,7 +541,7 @@ namespace osmscout {
                                     const Projection &projection,
                                     const MapParameter &parameter,
                                     const MapData & /*data*/) {
-    DoubleRectangle viewport(0.0, 0.0, (double) projection.GetWidth(), (double) projection.GetHeight());
+    ScreenVectorRectangle viewport(0.0, 0.0, (double) projection.GetWidth(), (double) projection.GetHeight());
     m_labelLayouter.SetViewport(viewport);
     m_labelLayouter.SetLayoutOverlap(projection.ConvertWidthToPixel(parameter.GetLabelLayouterOverlap()));
   }
@@ -613,17 +613,19 @@ namespace osmscout {
 
   void MapPainterGDI::RegisterRegularLabel(const Projection &projection,
                                            const MapParameter &parameter,
+                                           const ObjectFileRef& ref,
                                            const std::vector<LabelData> &labels,
                                            const Vertex2D &position,
                                            double objectWidth) {
-    m_labelLayouter.RegisterLabel(projection, parameter, position, labels, objectWidth);
+    m_labelLayouter.RegisterLabel(projection, parameter, ref, position, labels, objectWidth);
   }
 
   void MapPainterGDI::RegisterContourLabel(const Projection &projection,
                                            const MapParameter &parameter,
+                                           const ObjectFileRef& ref,
                                            const PathLabelData &label,
                                            const LabelPath &labelPath) {
-    m_labelLayouter.RegisterContourLabel(projection, parameter, label, labelPath);
+    m_labelLayouter.RegisterContourLabel(projection, parameter, ref, label, labelPath);
   }
 
   void MapPainterGDI::DrawLabels(const Projection &projection,
@@ -639,7 +641,7 @@ namespace osmscout {
   void MapPainterGDI::DrawSymbol(const Projection &projection,
                                  const MapParameter & /*parameter*/,
                                  const Symbol &symbol,
-                                 double x, double y,
+                                 const Vertex2D& screenPos,
                                  double /*scaleFactor*/) {
     Gdiplus::Pen *pPen;
 
@@ -660,8 +662,8 @@ namespace osmscout {
         pRender->pointBuffer.ResetAndReserve(polygon->GetCoords().size());
 
         for (const auto &pixel: polygon->GetCoords()) {
-          pRender->pointBuffer.AddPoint(x + projection.ConvertWidthToPixel(pixel.GetX()) - center.GetX(),
-                                        y + projection.ConvertWidthToPixel(pixel.GetY()) - center.GetY());
+          pRender->pointBuffer.AddPoint(screenPos.GetX() + projection.ConvertWidthToPixel(pixel.GetX()) - center.GetX(),
+                                        screenPos.GetY() + projection.ConvertWidthToPixel(pixel.GetY()) - center.GetY());
         }
 
         if (polygon->GetFillStyle()) {
@@ -680,8 +682,8 @@ namespace osmscout {
       } else if (rectangle != nullptr) {
         pPen = (rectangle->GetBorderStyle()) ? pRender->GetPen(rectangle->GetBorderStyle()) : nullptr;
         Gdiplus::RectF rect(
-          (Gdiplus::REAL) (x + projection.ConvertWidthToPixel(rectangle->GetTopLeft().GetX()) - center.GetX()),
-          (Gdiplus::REAL) (y + projection.ConvertWidthToPixel(rectangle->GetTopLeft().GetY()) - center.GetY()),
+          (Gdiplus::REAL) (screenPos.GetX() + projection.ConvertWidthToPixel(rectangle->GetTopLeft().GetX()) - center.GetX()),
+          (Gdiplus::REAL) (screenPos.GetY() + projection.ConvertWidthToPixel(rectangle->GetTopLeft().GetY()) - center.GetY()),
           (Gdiplus::REAL) (projection.ConvertWidthToPixel(rectangle->GetWidth())),
           (Gdiplus::REAL) (projection.ConvertWidthToPixel(rectangle->GetHeight()))
         );
@@ -698,9 +700,9 @@ namespace osmscout {
       } else if (circle != nullptr) {
         pPen = (circle->GetBorderStyle()) ? pRender->GetPen(circle->GetBorderStyle()) : nullptr;
         Gdiplus::RectF rect(
-          (Gdiplus::REAL) (x + projection.ConvertWidthToPixel(circle->GetCenter().GetX()) - center.GetX() -
+          (Gdiplus::REAL) (screenPos.GetX() + projection.ConvertWidthToPixel(circle->GetCenter().GetX()) - center.GetX() -
                            2 * projection.ConvertWidthToPixel(circle->GetRadius())),
-          (Gdiplus::REAL) (y + projection.ConvertWidthToPixel(circle->GetCenter().GetY()) - center.GetY() -
+          (Gdiplus::REAL) (screenPos.GetY() + projection.ConvertWidthToPixel(circle->GetCenter().GetY()) - center.GetY() -
                            2 * projection.ConvertWidthToPixel(circle->GetRadius())),
           (Gdiplus::REAL) (2 * projection.ConvertWidthToPixel(circle->GetRadius())),
           (Gdiplus::REAL) (2 * projection.ConvertWidthToPixel(circle->GetRadius()))
@@ -720,13 +722,16 @@ namespace osmscout {
   }
 
   void MapPainterGDI::DrawIcon(const IconStyle *style,
-                               double x, double y,
+                               const Vertex2D& centerPos,
                                double width, double height) {
     RENDEROBJECT(pRender);
     Gdiplus::Image *pImage = pRender->GetIcon(style->GetIconId());
 
     if (pImage != nullptr) {
-      pRender->m_pGraphics->DrawImage(pImage, (INT) (x - width / 2.0), (INT) (y - height / 2.0), (INT) width,
+      pRender->m_pGraphics->DrawImage(pImage,
+                                      (INT) (centerPos.GetX() - width / 2.0),
+                                      (INT) (centerPos.GetY() - height / 2.0),
+                                      (INT) width,
                                       (INT) height);
     }
   }
