@@ -19,15 +19,14 @@
 
 #include <osmscoutmap/StyleConfig.h>
 
-#include <cstring>
 #include <set>
-#include <sstream>
 #include <algorithm>
 
 #include <osmscout/system/Assert.h>
 
-#include <osmscout/util/File.h>
-#include <osmscout/util/Logger.h>
+#include <osmscout/log/Logger.h>
+
+#include <osmscout/io/File.h>
 
 #include <osmscoutmap/oss/Parser.h>
 #include <osmscoutmap/oss/Scanner.h>
@@ -1604,14 +1603,16 @@ namespace osmscout {
   bool StyleConfig::LoadContent(const std::string& filename,
                                 const std::string& content,
                                 ColorPostprocessor colorPostprocessor,
-                                bool submodule)
+                                bool submodule,
+                                Log &log)
   {
     oss::Scanner *scanner=new oss::Scanner((const unsigned char *)content.c_str(),
                                            content.length());
     oss::Parser  *parser=new oss::Parser(scanner,
                                          filename,
                                          *this,
-                                         colorPostprocessor);
+                                         colorPostprocessor,
+                                         log);
     parser->Parse();
 
     bool success=!parser->errors->hasErrors;
@@ -1622,16 +1623,16 @@ namespace osmscout {
     for (const auto& err : parser->errors->errors) {
       switch(err.type) {
         case oss::Errors::Err::Symbol:
-          errors.push_back(std::to_string(err.line)+","+std::to_string(err.column)+std::string(" Symbol:")+err.text);
+          errors.push_back(StyleError(StyleError::Symbol, err.line, err.column, err.text));
           break;
         case oss::Errors::Err::Error:
-          errors.push_back(std::to_string(err.line)+","+std::to_string(err.column)+std::string(" Error:")+err.text);
+          errors.push_back(StyleError(StyleError::Error, err.line, err.column, err.text));
           break;
         case oss::Errors::Err::Warning:
-          warnings.push_back(std::to_string(err.line)+","+std::to_string(err.column)+std::string(" Warning:")+err.text);
+          warnings.push_back(StyleError(StyleError::Warning, err.line, err.column, err.text));
           break;
         case oss::Errors::Err::Exception:
-          errors.push_back(std::to_string(err.line)+","+std::to_string(err.column)+std::string(" Exception:")+err.text);
+          errors.push_back(StyleError(StyleError::Exception, err.line, err.column, err.text));
           break;
         default:
           break;
@@ -1660,7 +1661,8 @@ namespace osmscout {
    */
   bool StyleConfig::Load(const std::string& styleFile,
                          ColorPostprocessor colorPostprocessor,
-                         bool submodule)
+                         bool submodule,
+                         Log &log)
   {
     StopClock  timer;
     bool       success=false;
@@ -1699,7 +1701,8 @@ namespace osmscout {
       success=LoadContent(styleFile,
                           std::string((const char *)content,fileSize),
                           colorPostprocessor,
-                          submodule);
+                          submodule,
+                          log);
 
       delete [] content;
 
@@ -1714,12 +1717,12 @@ namespace osmscout {
     return success;
   }
 
-  const std::list<std::string>& StyleConfig::GetErrors() const
+  const std::list<StyleError>& StyleConfig::GetErrors() const
   {
     return errors;
   }
 
-  const std::list<std::string>& StyleConfig::GetWarnings() const
+  const std::list<StyleError>& StyleConfig::GetWarnings() const
   {
     return warnings;
   }
