@@ -65,6 +65,8 @@ namespace osmscout {
   const char* const RouteDescription::LANES_DESC             = "Lanes";
   /** Constant for a description of suggested route lanes (SuggestedLaneDescription) */
   const char* const RouteDescription::SUGGESTED_LANES_DESC   = "SuggestedLanes";
+  /** Constant for a description of a via on the rote (first node of a route section) */
+  const char* const RouteDescription::NODE_VIA_DESC          = "NodeVia";
 
   RouteDescription::StartDescription::StartDescription(const std::string& description)
   : description(description)
@@ -478,7 +480,7 @@ namespace osmscout {
 
   RouteDescription::LaneDescription::LaneDescription(bool oneway,
                                                      uint8_t laneCount,
-                                                     const std::vector<std::string> &laneTurns)
+                                                     const std::vector<LaneTurn> &laneTurns)
                                                      : oneway(oneway), laneCount(laneCount), laneTurns(laneTurns)
   {}
 
@@ -492,13 +494,9 @@ namespace osmscout {
     if (!laneTurns.empty()){
       ss << " :";
     }
-    for_each(laneTurns.begin(), laneTurns.end(), [&ss] (const std::string& s) {
+    for_each(laneTurns.begin(), laneTurns.end(), [&ss] (const LaneTurn& turn) {
       ss << " ";
-      if (s.empty()){
-        ss << "<unspecified>";
-      } else {
-        ss << s;
-      }
+      ss << LaneTurnString(turn);
     });
 
     return ss.str();
@@ -529,6 +527,11 @@ namespace osmscout {
     return ss.str();
   }
 
+  std::string RouteDescription::ViaDescription::GetDebugString() const
+  {
+    return "Section number: "+std::to_string(sectionNumber)+" node count: "+std::to_string(nodeCount);
+  }
+
   bool RouteDescription::Node::HasDescription(const char* name) const
   {
     std::unordered_map<std::string,DescriptionRef>::const_iterator entry;
